@@ -13,7 +13,7 @@ impl From<crate::R<DBG_PADOE_SPEC>> for R {
         R(reader)
     }
 }
-#[doc = "Read to sample the pad output enables (direction) PIO is currently driving to the GPIOs.  
+#[doc = "Read to sample the pad output enables (direction) PIO is currently driving to the GPIOs. On RP2040 there are 30 GPIOs, so the two most significant bits are hardwired to 0.  
 
 This register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).  
 
