@@ -322,7 +322,7 @@ impl<'a> BUS_RESET_W<'a> {
         self.w
     }
 }
-#[doc = "Field `VBUS_DETECT` reader - Source: SIE_STATUS.VBUS_DETECT"]
+#[doc = "Field `VBUS_DETECT` reader - Source: SIE_STATUS.VBUS_DETECTED"]
 pub struct VBUS_DETECT_R(crate::FieldReader<bool, bool>);
 impl VBUS_DETECT_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -336,7 +336,7 @@ impl core::ops::Deref for VBUS_DETECT_R {
         &self.0
     }
 }
-#[doc = "Field `VBUS_DETECT` writer - Source: SIE_STATUS.VBUS_DETECT"]
+#[doc = "Field `VBUS_DETECT` writer - Source: SIE_STATUS.VBUS_DETECTED"]
 pub struct VBUS_DETECT_W<'a> {
     w: &'a mut W,
 }
@@ -795,7 +795,7 @@ impl R {
     pub fn bus_reset(&self) -> BUS_RESET_R {
         BUS_RESET_R::new(((self.bits >> 12) & 0x01) != 0)
     }
-    #[doc = "Bit 11 - Source: SIE_STATUS.VBUS_DETECT"]
+    #[doc = "Bit 11 - Source: SIE_STATUS.VBUS_DETECTED"]
     #[inline(always)]
     pub fn vbus_detect(&self) -> VBUS_DETECT_R {
         VBUS_DETECT_R::new(((self.bits >> 11) & 0x01) != 0)
@@ -897,7 +897,7 @@ impl W {
     pub fn bus_reset(&mut self) -> BUS_RESET_W {
         BUS_RESET_W { w: self }
     }
-    #[doc = "Bit 11 - Source: SIE_STATUS.VBUS_DETECT"]
+    #[doc = "Bit 11 - Source: SIE_STATUS.VBUS_DETECTED"]
     #[inline(always)]
     pub fn vbus_detect(&mut self) -> VBUS_DETECT_W {
         VBUS_DETECT_W { w: self }
